@@ -125,9 +125,9 @@ dict_products_scipost = {
 # as '01' (always two digits for an integer)
 # The following  nint_mf = '02' and str_mf='P' will give
 # P01, P02, P03 etc as suffixes for the naming convention
-default_nds = 3
-default_strds = 'OB'
-default_strfield = 'P'
+default_ndigits = 3
+default_str_dataset = 'OB'
+default_str_pointing = 'P'
 
 # -- END ---------------------------------------------------------------#
 
@@ -150,11 +150,11 @@ dict_user_folders = {
             # Calibration files (specific to OBs)
             "root": "/data/beegfs/astro-storage/groups/schinnerer/PHANGS/MUSE/live/",
             # Default prefix for Datasets
-            "str_dataset": default_strds,
-            # Default prefix for Fields
-            "str_field": default_strfield,
+            "str_dataset": default_str_dataset,
+            # Default prefix for Pointings
+            "str_pointing": default_str_pointing,
             # Default number of digits for Blocks
-            "ndigits": default_nds
+            "ndigits": default_ndigits
             }
 
 # Default initialisation file
@@ -328,13 +328,13 @@ mjd_names = {'table': "MJD_OBS", 'image': "MJD-OBS"}
 date_names = {'table': "DATE_OBS", 'image': "DATE-OBS"}
 tpl_names = {'table': "TPL_START", 'image': "HIERARCH ESO TPL START"}
 iexpo_names = {'table': "IEXPO_OBS", 'image': "MUSEPIPE_IEXPO"}
-field_names = {'table': "FIELD_OBS", 'image': "MUSEPIPE_FIELD"}
+dataset_names = {'table': "DATASET_OBS", 'image': "MUSEPIPE_DATASET"}
 
 default_offset_table = {'date': [date_names['table'], 'S23', ""],
                         'mjd': [mjd_names['table'], 'f8', 0.0],
                         'tpls': [tpl_names['table'], 'S19', ""],
                         'iexpo': [iexpo_names['table'], 'i4', 0],
-                        'field': [iexpo_names['table'], 'i4', 0],
+                        'dataset': [iexpo_names['table'], 'i4', 0],
                         'ora': ["RA_OFFSET", 'f8', 0.0],
                         'odec': ["DEC_OFFSET", 'f8', 0.0],
                         'scale': ["FLUX_SCALE", 'f8', 1.0]}
@@ -371,7 +371,7 @@ dict_recipes_per_num = {1: 'bias',
                         11: 'align_bygroup',
                         12: 'scipost_perexpo',
                         13: 'scipost_sky',
-                        14: 'combine_field'
+                        14: 'combine_dataset'
                         }
 
 # Value by default for certain fixed parameters in recipes
