@@ -64,10 +64,12 @@ from .init_musepipe import InitMuseParameters
 from .recipes_pipe import PipeRecipes
 from .prep_recipes_pipe import PipePrep
 from . import util_pipe as upipe
+from .util_pipe import analyse_musemode
 from .config_pipe import (suffix_rawfiles, suffix_prealign, suffix_checkalign,
-    listexpo_files, dict_listObject, dict_listMaster, dict_listMasterObject,
-    dict_expotypes, dict_geo_astrowcs_table, exclude_list_checkmode,
-    dict_astrogeo, )
+                          listexpo_files, dict_listObject, dict_listMaster,
+                          dict_listMasterObject, dict_expotypes, dict_geo_astrowcs_table,
+                          list_exclude_checkmode, list_fieldspecific_checkmode, dict_astrogeo,
+                          list_musemodes, dict_default_for_recipes)
 
 __version__ = '2.0.2 (25/09/2019)'
 
@@ -95,19 +97,6 @@ class PipeObject(object):
         self._info = info
 
 
-def lower_rep(text):
-    """Lower the text and return it after removing all underscores
-
-    Args:
-        text (str): text to treat
-
-    Returns:
-        updated text (with removed underscores and lower-cased)
-
-    """
-    return text.replace("_", "").lower()
-
-
 class MusePipe(PipePrep, PipeRecipes):
     """Main Class to define and run the MUSE pipeline, given a certain galaxy
     name. This is the main class used throughout the running of the pipeline
@@ -119,7 +108,7 @@ class MusePipe(PipePrep, PipeRecipes):
     described.
     """
 
-    def __init__(self, targetname=None, pointing=0, folder_config="Config/",
+    def __init__(self, targetname=None, dataset=1, folder_config="Config/",
                  rc_filename=None, cal_filename=None, log_filename="MusePipe.log",
                  verbose=True, musemode="WFM-NOAO-N", checkmode=True,
                  strong_checkmode=False, **kwargs):
@@ -129,7 +118,7 @@ class MusePipe(PipePrep, PipeRecipes):
 
         Args:
             targetname (str): Name of the target (e.g., 'NGC1208').
-            pointing (int): Number of the pointing to consider
+            dataset (int): dataset number to consider
             folder_config (str): Folder name for the configuration files
             rc_filename (str): Name of the input configuration file with
                 the root folders
@@ -190,18 +179,15 @@ class MusePipe(PipePrep, PipeRecipes):
 
         # Use time dependent geo_table
         self._time_astrometry = kwargs.pop("time_astrometry", False)
+        upipe.print_info(f"Time_astrometry option will now be set to {self._time_astrometry}")
 
         # Set alignment saving option
         self._save_alignment_images = kwargs.pop("save_alignment_images", True)
 
         #        super(MusePipe, self).__init__(**kwargs)
-        # Filter for alignment
-        self.filter_for_alignment = kwargs.pop("filter_for_alignment", "Cousins_R")
-        self.filter_list = kwargs.pop("filter_list", "white")
 
         # Setting the default attibutes #####################
         self.targetname = targetname
-        self.pointing = pointing
         self.vsystemic = np.float(kwargs.pop("vsystemic", 0.))
 
         # Setting other default attributes
@@ -212,10 +198,14 @@ class MusePipe(PipePrep, PipeRecipes):
 
         # Further reduction options =====================================
         # Mode of the observations
+        self._list_musemodes = list_musemodes
         self.musemode = musemode
+        # Printing the muse mode which also serves as a test to see if allowed
+        upipe.print_info(f"Input MUSE mode = {self.musemode}")
+
         # Checking if mode is correct
         self.checkmode = checkmode
-        # Checking if mode is correct also for BIAS & DARK
+        # Checking if mode is correct also for BIAS & DARK and also ILLUM!
         self.strong_checkmode = strong_checkmode
         # End of parameter settings #########################
 
@@ -224,20 +214,29 @@ class MusePipe(PipePrep, PipeRecipes):
         last_recipe = kwargs.pop("last_recipe", None)
         init_raw_table = kwargs.pop("init_raw_table", True)
 
+        # Filter for alignment
+        self.filter_for_alignment = kwargs.pop("filter_for_alignment", 
+                                               dict_default_for_recipes['filter_for_alignment'])
+        self.filter_list = kwargs.pop("filter_list", "white")
         # Init of the subclasses
-        PipePrep.__init__(self, first_recipe=first_recipe, last_recipe=last_recipe)
+        PipePrep.__init__(self, first_recipe=first_recipe,
+                          last_recipe=last_recipe)
         PipeRecipes.__init__(self, **kwargs)
 
+        # dataset
+        self.dataset = dataset
+
         # =========================================================== #
         # Setting up the folders and names for the data reduction
         # Can be initialised by either an rc_file, 
         # or a default rc_file or harcoded defaults.
         self.pipe_params = InitMuseParameters(folder_config=folder_config,
                                               rc_filename=rc_filename,
-                                              cal_filename=cal_filename, verbose=verbose)
+                                              cal_filename=cal_filename, 
+                                              verbose=verbose)
 
         # Setting up the relative path for the data, using Galaxy Name + Pointing
-        self.pipe_params.data = "{0}/P{1:02d}/".format(self.targetname, self.pointing)
+        self.pipe_params.data = f"{self.targetname}/{self._get_dataset_name()}"
 
         # Create full path folder 
         self.set_fullpath_names()
@@ -254,23 +253,27 @@ class MusePipe(PipePrep, PipeRecipes):
         # ==============================================
         # Creating the extra pipeline folder structure
         for folder in self.pipe_params._dict_input_folders:
-            upipe.safely_create_folder(self.pipe_params._dict_input_folders[folder], verbose=verbose)
+            upipe.safely_create_folder(self.pipe_params._dict_input_folders[folder],
+                                       verbose=verbose)
 
         # ==============================================
         # Creating the folder structure itself if needed
         for folder in self.pipe_params._dict_folders:
-            upipe.safely_create_folder(self.pipe_params._dict_folders[folder], verbose=verbose)
+            upipe.safely_create_folder(self.pipe_params._dict_folders[folder],
+                                       verbose=verbose)
 
         # ==============================================
         # Init the Master exposure flag dictionary
         self.Master = {}
         for mastertype in dict_listMaster:
-            upipe.safely_create_folder(self._get_path_expo(mastertype, "master"), verbose=verbose)
+            upipe.safely_create_folder(self._get_path_expo(mastertype, "master"),
+                                       verbose=verbose)
             self.Master[mastertype] = False
 
         # Init the Object folder
         for objecttype in dict_listObject:
-            upipe.safely_create_folder(self._get_path_expo(objecttype, "processed"), verbose=verbose)
+            upipe.safely_create_folder(self._get_path_expo(objecttype, "processed"),
+                                       verbose=verbose)
 
         self._dict_listMasterObject = dict_listMasterObject
 
@@ -296,6 +299,45 @@ class MusePipe(PipePrep, PipeRecipes):
             self._raw_table_initialised = False
         self.read_all_astro_tables()
 
+    def print_musemodes(self):
+        """Print out the list of allowed muse modes
+        """
+        upipe.print_warning(f"List of allowed Musemodes = {self._list_musemodes}")
+
+    @property
+    def musemode(self):
+        """Mode for MUSE
+        """
+        umuse = self._musemode.upper()
+        if umuse not in self._list_musemodes:
+            upipe.print_error("Provided musemode {umuse} not supported")
+            self.print_musemodes()
+            return None
+
+        return self._musemode
+
+    @musemode.setter
+    def musemode(self, val):
+        self._musemode = val
+
+    @property
+    def _fieldmode(self):
+        """Property to return the field mode for MUSE
+        """
+        return analyse_musemode(self.musemode, 'field')
+
+    @property
+    def _aomode(self):
+        """Property to return the AO mode for MUSE
+        """
+        return analyse_musemode(self.musemode, 'ao')
+
+    @property
+    def _lrangemode(self):
+        """Property to return the lambda range (N or E) mode for MUSE
+        """
+        return analyse_musemode(self.musemode, 'lrange')
+
     def _init_geoastro_dates(self):
         """Initialise the dictionary for the geo and astrometry files
         Transforms the dates into datetimes
@@ -308,7 +350,7 @@ class MusePipe(PipePrep, PipeRecipes):
                                "%Y-%m-%d").date()
             self._dict_geoastro[name] = [startd, endd]
 
-    def retrieve_geoastro_name(self, date_str, filetype='geo', mode='wfm'):
+    def retrieve_geoastro_name(self, date_str, filetype='geo', fieldmode='wfm'):
         """Retrieving the astrometry or geometry fits file name
 
         Parameters
@@ -317,11 +359,11 @@ class MusePipe(PipePrep, PipeRecipes):
             Date as a string (DD/MM/YYYY)
         filetype: str
             'geo' or 'astro', type of the needed file
-        mode: str
+        fieldmode: str
             'wfm' or 'nfm' - MUSE mode
         """
         dict_pre = {'geo': 'geometry_table',
-                   'astro': 'astrometry_wcs'}
+                    'astro': 'astrometry_wcs'}
         if filetype not in dict_pre:
             upipe.print_error("Could not decipher the filetype option "
                               "in retrieve_geoastro")
@@ -337,14 +379,16 @@ class MusePipe(PipePrep, PipeRecipes):
         ga_suffix = near[min(near.keys())]
         # Build the name with the prefix, suffix and mode
         ga_name = "{0}_{1}_{2}.fits".format(dict_pre[filetype],
-                                            mode, ga_suffix)
+                                            fieldmode, ga_suffix)
         return ga_name
 
     def _set_option_astropy_table(self, overwrite=None, update=None):
         """Set the options for overwriting or updating the astropy tables
         """
-        if overwrite is not None: self._overwrite_astropy_table = overwrite
-        if update is not None: self._update_astropy_table = update
+        if overwrite is not None:
+            self._overwrite_astropy_table = overwrite
+        if update is not None:
+            self._update_astropy_table = update
 
     def goto_origfolder(self, addtolog=False):
         """Go back to original folder
@@ -370,6 +414,8 @@ class MusePipe(PipePrep, PipeRecipes):
 
         Parameters
         ----------
+        newpath: str
+            Path where to go to
         addtolog: bool [False]
             Adding the folder move to the log file
         """
@@ -417,6 +463,12 @@ class MusePipe(PipePrep, PipeRecipes):
             setattr(self.paths, name, joinpath(self.paths.target,
                                                self.pipe_params._dict_folders_target[name]))
 
+    def _get_dataset_name(self):
+        """Reporting the _get_dataset_name from the InitMuseParam
+        class
+        """
+        return self.pipe_params._get_dataset_name(self.dataset)
+
     def _reset_tables(self):
         """Reseting the astropy Tables for expotypes
         """
@@ -482,22 +534,23 @@ class MusePipe(PipePrep, PipeRecipes):
 
         # ---- File exists - we READ it ------------------- #
         overwrite = kwargs.pop("overwrite", self._overwrite_astropy_table)
+        scan_raw = True
         if os.path.isfile(name_table):
             if overwrite:
                 upipe.print_warning("The raw-files table will be overwritten",
                                     pipe=self)
             else:
-                upipe.print_warning("The raw files table already exists",
-                                    pipe=self)
-                upipe.print_warning("If you wish to overwrite it, "
-                                    " please turn on the 'overwrite_astropy_table' option to 'True'",
-                                    pipe=self)
-                upipe.print_warning("In the meantime, the existing table will be read and used",
+                upipe.print_warning("The raw files table already exists.\n"
+                                    "If you wish to overwrite it, please turn "
+                                    "on the 'overwrite_astropy_table' option to "
+                                    "'True'.\n In the meantime, the existing "
+                                    "table will be read and used.",
                                     pipe=self)
                 self.Tables.Rawfiles = self.read_astropy_table('RAWFILES', "raw")
+                scan_raw = False
 
         # ---- File does not exist - we create it ---------- #
-        if overwrite:
+        if scan_raw:
             # Check the raw folder
             self.goto_folder(self.paths.rawfiles)
             # Get the list of files from the Raw data folder
@@ -605,9 +658,13 @@ class MusePipe(PipePrep, PipeRecipes):
             table_to_save = copy.copy(tpl_gtable)
 
         # If the file already exists
+        # If overwrite is True we just continue and overwrite the table
         if os.path.isfile(full_tablename):
+            if self._overwrite_astropy_table:
+                upipe.print_warning(f"Astropy Table {fits_tablename} "
+                                    f"exists and will be overwritten")
             # Check if we update
-            if self._update_astropy_table:
+            elif self._update_astropy_table:
                 # Reading the existing table
                 upipe.print_warning("Reading the existing Astropy table {0} "
                                     "in folder {1}".format(fits_tablename,
@@ -625,7 +682,7 @@ class MusePipe(PipePrep, PipeRecipes):
                     return
 
             # Check if we want to overwrite or add the line in
-            elif not self._overwrite_astropy_table:
+            else:
                 upipe.print_warning("Astropy Table {0} already exists, "
                                     " use overwrite_astropy_table to "
                                     "overwrite it".format(fits_tablename),
@@ -637,6 +694,18 @@ class MusePipe(PipePrep, PipeRecipes):
 
     def sort_raw_tables(self, checkmode=None, strong_checkmode=None):
         """Provide lists of exposures with types defined in the dictionary
+        after excluding those with the wrong MUSE mode if checkmode is set up.
+
+        Input
+        -----
+        checkmode: boolean
+            Checking the MUSE mode or not. Default to None, namely it won't use
+            the value set here but the value predefined in self.checkmode.
+        strong_checkmode: boolean
+            Strong check, namely in case you still wish to force the MUSE mode
+            even for files which are not mode specific (e.g., BIAS). 
+            Default to None, namely it uses the self.strong_checkmode which was
+            already set up at start.
         """
         if checkmode is not None:
             self.checkmode = checkmode
@@ -649,13 +718,22 @@ class MusePipe(PipePrep, PipeRecipes):
             return
 
         # Sorting alphabetically (thus by date)
+        if self.checkmode:
+            upipe.print_warning(f"Checkmode is True: the MUSE Mode will be checked.")
+            upipe.print_warning(f"All Raw files which do have musemode = {self.musemode} "
+                                f"and are mode specific (e.g., Flat field) will be masked.")
+            upipe.print_warning(f"If you wish otherwise, set checkmode to False "
+                                f"[but this may impact the data reduction].")
         for expotype in dict_expotypes:
             try:
                 mask = (self.Tables.Rawfiles['type'] == dict_expotypes[expotype])
                 if self.checkmode:
-                    maskmode = (self.Tables.Rawfiles['mode'] == self.musemode)
-                    if (expotype.upper() not in exclude_list_checkmode) or self.strong_checkmode:
-                        mask = maskmode & mask
+                    if expotype.upper() in list_fieldspecific_checkmode:
+                        maskmode = [self._fieldmode == analyse_musemode(value, 'field') 
+                                    for value in self.Tables.Rawfiles['mode']]
+                    elif (expotype.upper() not in list_exclude_checkmode) or self.strong_checkmode:
+                        maskmode = (self.Tables.Rawfiles['mode'] == self.musemode)
+                    mask = maskmode & mask
                 setattr(self.Tables.Raw, self._get_attr_expo(expotype),
                         self.Tables.Rawfiles[mask])
             except AttributeError:
@@ -676,23 +754,23 @@ class MusePipe(PipePrep, PipeRecipes):
         try:
             return getattr(self._dict_tables[stage], self._get_attr_expo(expotype))
         except AttributeError:
-            upipe.print_error("No attributed table with expotype {0} and stage {1}".format(expotype, stage))
+            upipe.print_error(f"No attributed table with expotype {expotype} and stage {stage}")
             return Table()
 
-    def _read_offset_table(self, offset_table_name=None, folder_offset_table=None):
+    def _read_offset_table(self, name_offset_table=None, folder_offset_table=None):
         """Reading the Offset Table
 
         Input
         -----
-        offset_table_name: str
+        name_offset_table: str
             Name of the offset table
             Default is None
         folder_offset_table: str
             Name of the folder to find the offset table
             Default is None
         """
-        self.offset_table_name = offset_table_name
-        if self.offset_table_name is None:
+        self.name_offset_table = name_offset_table
+        if self.name_offset_table is None:
             upipe.print_warning("No Offset table name given")
             self.offset_table = Table()
             return
@@ -703,16 +781,16 @@ class MusePipe(PipePrep, PipeRecipes):
         else:
             self.folder_offset_table = folder_offset_table
 
-        full_offset_table_name = joinpath(self.folder_offset_table,
-                                          self.offset_table_name)
-        if not os.path.isfile(full_offset_table_name):
+        fullname_offset_table = joinpath(self.folder_offset_table,
+                                         self.name_offset_table)
+        if not os.path.isfile(fullname_offset_table):
             upipe.print_error("Offset table [{0}] not found".format(
-                full_offset_table_name))
+                fullname_offset_table))
             self.offset_table = Table()
             return
 
         # Opening the offset table
-        self.offset_table = Table.read(full_offset_table_name)
+        self.offset_table = Table.read(fullname_offset_table)
 
     def _select_closest_mjd(self, mjdin, group_table):
         """Get the closest frame within the expotype
